var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head>\n\
<link href=\"../../style/prettify.css\" type=\"text/css\" rel=\"stylesheet\" />\n\
<script type=\"text/javascript\" src=\"../../scripts/prettify.js\"></script><script src=\"../../scripts/lib/jquery-1.11.1.min.js\" type=\"text/javascript\"></script><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" /><meta http-equiv=\"Content-Style-Type\" content=\"text/css\" /><meta name=\"generator\" content=\"pandoc\" /><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\" /><script type=\"text/javascript\" src=\"../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Accessing Qt and Maya controls</title>\n\
   </head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style><script>$(document).ready(function() { yepnope.injectJs(\"./scripts/multireflink.js\"); });</script><script>$(document).ready(function () { prettyPrint(); } );</script><script></script><script></script><div id=\"reflinkdiv\"></div>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Accessing Qt and Maya controls</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"accessing-qt-and-maya-controls\"></a></div>\n\
<p>Controls created directly using Qt are generally not recognized by Maya&#39;s UI commands.</p>\n\
<p>They are not listed by the <span class=\'code\'>isUI</span> command, and the commands for specific types of controls, such as the <span class=\'code\'>button</span> command, will not recognize them. Commands such as <span class=\'code\'>button</span> only recognize controls they created.</p>\n\
<p>However, if <span class=\'code\'>setObjectName()</span> was used to give the Qt control a unique name, you can use the <span class=\'code\'>control</span> command to test for the existence of the control and perform basic operations on the control.</p>\n\
<p>For example, if you assign your button a unique name:</p>\n\
<div class=\"codeBlock\"><pre class=\"prettyprint lang-cpp\">   button = new MyAction(&quot;Perform Action&quot;);\n\
   button-&gt;setObjectName(&quot;myActionButton&quot;);\n\
</pre></div><p>then you can use the <span class=\'code\'>control</span> command to hide the button:</p>\n\
<div class=\"codeBlock\"><pre class=\"prettyprint lang-sh\">if (`control -q -exists myActionButton`) {\n\
   control -e -visible false myActionButton;\n\
}\n\
</pre></div><p>You can use Qt to access UI elements created using Maya commands.</p>\n\
<p>The <span class=\'code\'><a href=\"javascript:void(0)\" data-symbol=\"MQtUtil\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;cpp_ref/class_m_qt_util.html&quot;,&quot;title&quot;:&quot;C++ API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">MQtUtil</a></span> C++ class provides methods for retrieving the Qt object underlying a Maya control, layout, window, or menu item.</p>\n\
<p>For example, if you created a Maya checkBox control named <span class=\'code\'>myCheckBox</span> using the <span class=\'code\'>checkBox</span> command, you can use <span class=\'code\'><a href=\"javascript:void(0)\" data-symbol=\"MQtUtil::findControl()\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;cpp_ref/class_m_qt_util.html#a4117d34bd18ee0fa108c4952bda68e94&quot;,&quot;title&quot;:&quot;C++ API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">MQtUtil::findControl()</a></span> class to retrieve the checkBox&#39;s <span class=\'code\'>QWidget</span> pointer and cast it appropriately.</p>\n\
<div class=\"codeBlock\"><pre class=\"prettyprint lang-cpp\">QWidget* control = <a href=\"javascript:void(0)\" data-symbol=\"MQtUtil::findControl\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;cpp_ref/class_m_qt_util.html#a4117d34bd18ee0fa108c4952bda68e94&quot;,&quot;title&quot;:&quot;C++ API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">MQtUtil::findControl</a>(&quot;myCheckBox&quot;);\n\
if (control) {\n\
   QCheckBox* cb = qobject_cast&lt;QCheckBox*&gt;(control);\n\
}\n\
<blockquote>\n\
</blockquote></pre></div><p><strong>Important:</strong> If your control&#39;s type does not match the type you cast it to, the cast operation will return <span class=\'code\'>nullptr</span>.</p>\n\
\n\
<p>You can then use the <span class=\'code\'>QWidget</span> pointer to access any of the <span class=\'code\'>QCheckBox</span>&#39;s properties, or call any method on the <span class=\'code\'>QCheckBox</span>:</p>\n\
<div class=\"codeBlock\"><pre class=\"prettyprint lang-cpp\">if (cb) {\n\
    if (cb-&gt;isChecked()) {\n\
        <a href=\"javascript:void(0)\" data-symbol=\"MGlobal::displayInfo\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;cpp_ref/class_m_global.html#a3d14e9f9ed022a80f664eac0136c2f7a&quot;,&quot;title&quot;:&quot;C++ API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">MGlobal::displayInfo</a>(&quot;myCheckBox is checked&quot;);\n\
      } else {\n\
          <a href=\"javascript:void(0)\" data-symbol=\"MGlobal::displayInfo\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;cpp_ref/class_m_global.html#a3d14e9f9ed022a80f664eac0136c2f7a&quot;,&quot;title&quot;:&quot;C++ API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">MGlobal::displayInfo</a>(&quot;myCheckBox is not checked&quot;);\n\
      }\n\
   }\n\
</pre></div>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";